#
# spec file for package apache-commons-math
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global base_name       math
%global short_name      commons-%{base_name}
Name:           apache-commons-math
Version:        3.6.1
Release:        9.3
Summary:        The Apache Commons Mathematics Library
License:        Apache-2.0
URL:            http://commons.apache.org/%{base_name}/
Source:         http://www.apache.org/dist/commons/%{base_name}/source/%{short_name}3-%{version}-src.tar.gz
BuildRequires:  java-devel >= 1.8
BuildRequires:  maven-local
BuildRequires:  mvn(org.apache.commons:commons-parent:pom:)
Provides:       apache-commons-math3 = %{version}
Obsoletes:      apache-commons-math3 < %{version}
BuildArch:      noarch

%description
Commons Math is a library of lightweight, self-contained mathematics and
statistics components addressing the most common problems not available in
the Java programming language or Commons Lang.

%package javadoc
Summary:        Javadoc for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%autosetup -n %{short_name}3-%{version}-src

%pom_remove_plugin :maven-antrun-plugin
%pom_remove_plugin :build-helper-maven-plugin

%build
%mvn_build -f -- \
    -Dproject.build.outputTimestamp=$(date -u -d @${SOURCE_DATE_EPOCH:-$(date +%%s)} +%%Y-%%m-%%dT%%H:%%M:%%SZ) \
    -Dmaven.compiler.source=1.8 -Dmaven.compiler.target=1.8

%install
%mvn_install

%files -f .mfiles
%license LICENSE.txt license-header.txt NOTICE.txt
%doc RELEASE-NOTES.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt

%changelog
* Sat Sep  9 2023 Fridrich Strba <fstrba@suse.com>
- Reproducible builds: use SOURCE_DATE_EPOCH for timestamp
* Sun Jun 19 2022 Michael Calmer <mc@suse.com>
- Obsolete apache-commons-math3 package (jsc#SLE-23217)
* Thu Feb 11 2021 Matthias Mailänder <mailaender@opensuse.org>
- use maven local
- drop commons-math3-3.6.1-notests.patch
* Mon Nov 11 2019 Fridrich Strba <fstrba@suse.com>
- Add alias to the maven artifact
- Clean-up the spec file
- Remove reference to the parent pom, since we don't build with
  maven
* Tue May 15 2018 fstrba@suse.com
- Build with source and target 8 to prepare for a possible removal
  of 1.6 compatibility
* Thu Sep 14 2017 fstrba@suse.com
- Fix build with jdk9 by specifying java source and target 1.6
- Added patch:
  * commons-math3-3.6.1-notests.patch
  - Disable unit tests, since they are bound to fail. The new
    methods of java.lang.StrictMath are not implemented in the
    org.apache.commons.math3.utils.FastMath and the unit tests
    bail out.
* Sun May 21 2017 tchvatal@suse.com
- Remove needless requires
* Fri May 19 2017 pcervinka@suse.com
- New build dependency: javapackages-local
- Fixed requires
* Fri Feb 24 2017 shshyukriev@suse.com
- Update to version 3.6.1
  * Minor bug fix release
* Fri Oct  9 2015 p.drouand@gmail.com
- Initial release (version 3.5)
